@@ -110,7 +110,8 @@ class Cache:
     on FastF1.
     """
     _CACHE_DIR = ''
-    _API_CORE_VERSION = 6  # version of the api parser code (unrelated to release version number)
+    # version of the api parser code (unrelated to release version number)
+    _API_CORE_VERSION = 7
     _IGNORE_VERSION = False
     _FORCE_RENEW = False
 
@@ -129,6 +130,9 @@ class Cache:
             force_renew (bool): Ignore existing cached data. Download data and update the cache instead.
             use_requests_cache (bool): Do caching of the raw GET and POST requests.
         """
+        # Allow users to use paths such as ~user or ~/
+        cache_dir = os.path.expanduser(cache_dir)
+
         if not os.path.exists(cache_dir):
             raise NotADirectoryError("Cache directory does not exist! Please check for typos or create it first.")
         cls._CACHE_DIR = cache_dir
@@ -642,7 +646,13 @@ def _laps_data_driver(driver_raw, empty_vals, drv):
             for trapkey, trapname in (('I1', 'SpeedI1'), ('I2', 'SpeedI2'), ('FL', 'SpeedFL'), ('ST', 'SpeedST')):
                 if val := recursive_dict_get(resp, 'Speeds', trapkey, 'Value'):
                     # speed has to be float because int does not support NaN
-                    drv_data[trapname][lapcnt - lap_offset] = float(val)
+                    if trapkey == 'ST':
+                        # the ST trap value can occur early enough in a new lap
+                        # that it needs to be excluded from the usual offset
+                        # logic, therefore the offset is ignored here
+                        drv_data[trapname][lapcnt] = float(val)
+                    else:
+                        drv_data[trapname][lapcnt - lap_offset] = float(val)
 
         if 'InPit' in resp:
             # 'InPit': True is received once when entering pits, False is received once when leaving
@@ -786,8 +796,10 @@ def _laps_data_driver(driver_raw, empty_vals, drv):
             break
 
     if integrity_errors:
-        logging.warning(f"Driver {drv: >2}: Encountered {len(integrity_errors)} timing integrity error(s) "
-                        f"near lap(s): {integrity_errors}")
+        logging.warning(
+            f"Driver {drv: >2}: Encountered {len(integrity_errors)} timing "
+            f"integrity error(s) near lap(s): {integrity_errors}.\n"
+            f"This might be a bug and should be reported.")
 
     return drv_data
 
@@ -933,15 +945,18 @@ def car_data(path, response=None, livedata=None):
         - Gear (int): [called 'nGear' in the data!]
         - Throttle (int): 0-100%
         - Brake (bool)
-        - DRS (int): 0-14 (Odd DRS is Disabled, Even DRS is Enabled) (More Research Needed)
-            | 0 =  Off
-            | 1 =  Off
-            | 2 =  (?)
-            | 3 =  (?)
-            | 8 =  Detected, Eligible once in Activation Zone (Noted Sometimes)
-            | 10 = On (Unknown Distinction)
-            | 12 = On (Unknown Distinction)
-            | 14 = On (Unknown Distinction)
+        - DRS (int): 0-14 (Odd DRS is Disabled, Even DRS is Enabled?)
+          (More Research Needed?)
+
+          - 0 =  Off
+          - 1 =  Off
+          - 2 =  (?)
+          - 3 =  (?)
+          - 8 =  Detected, Eligible once in Activation Zone (Noted Sometimes)
+          - 10 = On (Unknown Distinction)
+          - 12 = On (Unknown Distinction)
+          - 14 = On (Unknown Distinction)
+
         - Source (str): Indicates the source of a sample; 'car' for all values here
 
     The data stream has a sample rate of (usually) 240ms. The samples from the data streams for position data and
