@@ -388,6 +388,32 @@ def get_event_schedule(year, *, include_testing=True, force_ergast=False):
     return schedule
 
 
+def get_events_remaining(
+        dt=None, *, include_testing=True, force_ergast=False) \
+        -> 'EventSchedule':
+    """Create an :class:`~fastf1.events.EventSchedule` object for remaining season.
+
+    Args:
+        dt (datetime): Optional DateTime to get events after.
+        include_testing (bool): Include or exclude testing sessions from the
+            event schedule.
+        force_ergast (bool): Always use data from the ergast database to
+            create the event schedule
+
+    Returns:
+        :class:`~fastf1.events.EventSchedule`
+
+    .. versionadded:: 2.3
+    """
+    if dt is None:
+        dt = datetime.datetime.now()
+
+    events = get_event_schedule(
+        dt.year, include_testing=include_testing, force_ergast=force_ergast)
+    result = events.loc[events["EventDate"] >= dt]
+    return result
+
+
 def _get_schedule(year):
     response = Cache.requests_get(
         _SCHEDULE_BASE_URL + f"schedule_{year}.json"
@@ -746,8 +772,8 @@ class Event(pd.Series):
                 session_name = 'Sprint'
 
             if session_name not in self.values:
-                raise ValueError(f"No session of type '{identifier}' for "
-                                 f"this event")
+                raise ValueError(f"Session type '{identifier}' does not "
+                                 f"exist for this event")
         else:
             # by number
             if (float(num).is_integer()
@@ -783,7 +809,11 @@ class Event(pd.Series):
                              f"for this event")
         else:
             _name = mask.idxmax()
-            return self[f"{_name}Date"]
+            date = self[f"{_name}Date"]
+            if pd.isnull(date):
+                raise ValueError(f"Session type '{identifier}' does not "
+                                 f"exist for this event")
+            return date
 
     def get_session(self, identifier):
         """Return a session from this event.
@@ -803,8 +833,8 @@ class Event(pd.Series):
             # by name or abbreviation
             session_name = self.get_session_name(identifier)
             if session_name not in self.values:
-                raise ValueError(f"No session of type '{identifier}' for "
-                                 f"this event")
+                raise ValueError(f"Session type '{identifier}' does not "
+                                 f"exist for this event")
         else:
             # by number
             if (float(num).is_integer()
